==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebPivotValueDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotAggregatorDescriptionMetadata } from "./WebPivotAggregatorDescriptionMetadata";
import { WebPivotValueDetailDescription } from "./WebPivotValueDetailDescription";
/**
 * @hidden
 */
var WebPivotValueDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPivotValueDetailDescriptionMetadata, _super);
    function WebPivotValueDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPivotValueDetailDescriptionMetadata.b = function (a) {
        if (WebPivotValueDetailDescriptionMetadata.a == null) {
            WebPivotValueDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPivotValueDetailDescriptionMetadata.c(WebPivotValueDetailDescriptionMetadata.a);
        }
        if (a.j(WebPivotValueDetailDescriptionMetadata.a)) {
            return;
        }
        a.y(WebPivotValueDetailDescriptionMetadata.a);
        WebPivotAggregatorDescriptionMetadata.d(a);
    };
    WebPivotValueDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PivotValueDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("Member", "String");
        a.item("DisplayName", "String");
        a.item("Aggregate", "ExportedType:WebPivotAggregator");
        a.item("AggregateList", "Collection:WebPivotAggregator:PivotAggregatorCollection:WebPivotAggregator");
        a.item("Enabled", "Boolean");
        a.item("Styles", "Unknown");
        a.item("DataType", "ExportedType:string:GridColumnDataType");
        a.item("DataType@names", "String;Number;Boolean;Date;DateTime;Time;Currency;Percent;Image");
        a.item("FormatterRef", "EventRef::formatter");
    };
    WebPivotValueDetailDescriptionMetadata.d = function (a) {
        WebPivotValueDetailDescriptionMetadata.b(a);
        a.aa("WebPivotValueDetail", function () { return new WebPivotValueDetailDescription(); });
        a.z("WebPivotValueDetail", WebPivotValueDetailDescriptionMetadata.a);
    };
    WebPivotValueDetailDescriptionMetadata.$t = markType(WebPivotValueDetailDescriptionMetadata, 'WebPivotValueDetailDescriptionMetadata');
    WebPivotValueDetailDescriptionMetadata.a = null;
    return WebPivotValueDetailDescriptionMetadata;
}(Base));
export { WebPivotValueDetailDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebPivotValueDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotAggregatorDescriptionMetadata } from "./WebPivotAggregatorDescriptionMetadata";
import { WebPivotValueDetailDescription } from "./WebPivotValueDetailDescription";
/**
 * @hidden
 */
var WebPivotValueDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPivotValueDetailDescriptionMetadata, _super);
    function WebPivotValueDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPivotValueDetailDescriptionMetadata.b = function (a) {
        if (WebPivotValueDetailDescriptionMetadata.a == null) {
            WebPivotValueDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPivotValueDetailDescriptionMetadata.c(WebPivotValueDetailDescriptionMetadata.a);
        }
        if (a.k(WebPivotValueDetailDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebPivotValueDetailDescriptionMetadata.a);
        WebPivotAggregatorDescriptionMetadata.d(a);
    };
    WebPivotValueDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PivotValueDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Member", "String");
        a.item("DisplayName", "String");
        a.item("Aggregate", "ExportedType:WebPivotAggregator");
        a.item("AggregateList", "Collection:WebPivotAggregator:PivotAggregatorCollection:WebPivotAggregator");
        a.item("Enabled", "Boolean");
        a.item("Styles", "Unknown");
        a.item("DataType", "ExportedType:string:GridColumnDataType");
        a.item("DataType@stringUnion", "WebComponents;React");
        a.item("DataType@names", "String;Number;Boolean;Date;DateTime;Time;Currency;Percent;Image");
        a.item("FormatterRef", "EventRef::formatter");
    };
    WebPivotValueDetailDescriptionMetadata.d = function (a) {
        WebPivotValueDetailDescriptionMetadata.b(a);
        a.ac("WebPivotValueDetail", function () { return new WebPivotValueDetailDescription(); });
        a.ab("WebPivotValueDetail", WebPivotValueDetailDescriptionMetadata.a);
    };
    WebPivotValueDetailDescriptionMetadata.$t = markType(WebPivotValueDetailDescriptionMetadata, 'WebPivotValueDetailDescriptionMetadata');
    WebPivotValueDetailDescriptionMetadata.a = null;
    return WebPivotValueDetailDescriptionMetadata;
}(Base));
export { WebPivotValueDetailDescriptionMetadata };
